You are viewing a plain text version of this content. The canonical link for it is here.
Posted to derby-commits@db.apache.org by ma...@apache.org on 2008/01/17 17:52:39 UTC

svn commit: r612865 - /db/derby/code/trunk/java/client/org/apache/derby/client/am/PreparedStatement.java

Author: mamta
Date: Thu Jan 17 08:52:35 2008
New Revision: 612865

URL: http://svn.apache.org/viewvc?rev=612865&view=rev
Log:
While working on DERBY-2720, I removed national datatypes as one of the unsupported data
types(revision 612525) and that caused the test failure for SetObjectUnsupportedTest since 
we stopped recognizing national dataypes as one of the unsupported datatypes. The fix 
required changes in only one class which I had modified incorrectly in revision 612525.
This test failure was not caught earlier by my local runs of the test because I had used
JDK14 which has JDBC3 support and this paritcular test requires JDBC4 support. 


Modified:
    db/derby/code/trunk/java/client/org/apache/derby/client/am/PreparedStatement.java

Modified: db/derby/code/trunk/java/client/org/apache/derby/client/am/PreparedStatement.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/client/org/apache/derby/client/am/PreparedStatement.java?rev=612865&r1=612864&r2=612865&view=diff
==============================================================================
--- db/derby/code/trunk/java/client/org/apache/derby/client/am/PreparedStatement.java (original)
+++ db/derby/code/trunk/java/client/org/apache/derby/client/am/PreparedStatement.java Thu Jan 17 08:52:35 2008
@@ -2455,9 +2455,9 @@
         //
         // Throws: (...) SQLFeatureNotSupportedException - if
         // targetSqlType is a ARRAY, BLOB, CLOB, DATALINK,
         // JAVA_OBJECT, LONGNVARCHAR, REF, ROWID, SQLXML or 
     	// STRUCT data type and the JDBC driver does not
         // support this data type
         //
         // Of these types, we only support BLOB, CLOB and
         // (sort of) JAVA_OBJECT.
@@ -2465,6 +2465,9 @@
         switch (dataType) {
         case java.sql.Types.ARRAY:
         case java.sql.Types.DATALINK:
+        case JDBC40Translation.NCHAR:
+        case JDBC40Translation.NCLOB:
+        case JDBC40Translation.NVARCHAR:
         case JDBC40Translation.LONGNVARCHAR:
         case java.sql.Types.REF:
         case JDBC40Translation.ROWID:
@@ -2455,9 +2455,9 @@
         // Throws: (...) SQLFeatureNotSupportedException - if
         // targetSqlType is a ARRAY, BLOB, CLOB, DATALINK,
-        // JAVA_OBJECT, LONGNVARCHAR, REF, ROWID, SQLXML or 
-    	// STRUCT data type and the JDBC driver does not
-        // support this data type
+        // JAVA_OBJECT, NCHAR, NCLOB, NVARCHAR, LONGNVARCHAR, REF,
+        // ROWID, SQLXML or STRUCT data type and the JDBC driver does
+        // not support this data type
         //
         // Of these types, we only support BLOB, CLOB and